SonarrCommand class

Annotations
  • @Freezed.new()

Constructors

SonarrCommand({required int id, @JsonKey.new(unknownEnumValue: SonarrCommandName.unknown) SonarrCommandName? name, String? commandName, String? message, required SonarrCommandBody body, required SonarrCommandPriority priority, required SonarrCommandStatus status, required DateTime queued, DateTime? started, DateTime? ended, @DurationStringConverter.new() Duration? duration, String? exception, required SonarrCommandTrigger trigger, String? clientUserAgent, DateTime? stateChangeTime, required bool sendUpdatesToClient, required bool updateScheduledTask, DateTime? lastExecutionTime})
const
factory
SonarrCommand.fromJson(Map<String, Object?> json)
factory

Properties

body SonarrCommandBody
no setterinherited
clientUserAgent String?
no setterinherited
commandName String?
no setterinherited
copyWith → $SonarrCommandCopyWith<SonarrCommand>
no setterinherited
duration Duration?
no setterinherited
ended DateTime?
no setterinherited
exception String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
lastExecutionTime DateTime?
no setterinherited
message String?
no setterinherited
name SonarrCommandName?
no setterinherited
priority SonarrCommandPriority
no setterinherited
queued DateTime
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendUpdatesToClient bool
no setterinherited
started DateTime?
no setterinherited
stateChangeTime DateTime?
no setterinherited
status SonarrCommandStatus
no setterinherited
trigger SonarrCommandTrigger
no setterinherited
updateScheduledTask bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited