SonarrCommandSeasonSearch class

Annotations
  • @Freezed.new()

Constructors

SonarrCommandSeasonSearch({@Default.new(SonarrCommandName.seasonSearch) SonarrCommandName name, required int seriesId, required int seasonNumber})
const
factory
SonarrCommandSeasonSearch.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $SonarrCommandSeasonSearchCopyWith<SonarrCommandSeasonSearch>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name SonarrCommandName
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seasonNumber int
no setterinherited
seriesId int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited