SonarrConfig class

Annotations
  • @Freezed.new()

Constructors

SonarrConfig({required String host, required String apiKey, @JsonKey.new(includeFromJson: false, includeToJson: false) BaseOptions? options})
const
factory
SonarrConfig.fromJson(Map<String, Object?> json)
factory

Properties

apiKey String
no setterinherited
baseOptions BaseOptions
no setter
baseUrl String
no setter
copyWith → $SonarrConfigCopyWith<SonarrConfig>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
host String
no setterinherited
options BaseOptions?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited