SonarrRootFolder class

Annotations
  • @Freezed.new()

Constructors

SonarrRootFolder({int? id, String? path, bool? accessible, int? freeSpace, List<SonarrUnmappedFolder>? unmappedFolders})
const
factory
SonarrRootFolder.fromJson(Map<String, Object?> json)
factory

Properties

accessible bool?
no setterinherited
copyWith → $SonarrRootFolderCopyWith<SonarrRootFolder>
no setterinherited
freeSpace int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
path String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unmappedFolders List<SonarrUnmappedFolder>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited