SonarrTask class
- Annotations
-
- @Freezed.new()
Constructors
- SonarrTask({required int id, String? name, String? taskName, required int interval, required DateTime lastExecution, required DateTime lastStartTime, required DateTime nextExecution, @DurationStringConverter.new() required Duration lastDuration})
-
constfactory
-
SonarrTask.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $SonarrTaskCopyWith<
SonarrTask> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- interval → int
-
no setterinherited
- lastDuration → Duration
-
no setterinherited
- lastExecution → DateTime
-
no setterinherited
- lastStartTime → DateTime
-
no setterinherited
- name → String?
-
no setterinherited
- nextExecution → DateTime
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskName → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited